@@ -5,7 +5,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     17/08/2001
-## RCS-ID:      $Id: wx_overload.pl 2057 2007-06-18 23:03:00Z mbarbon $
+## RCS-ID:      $Id: wx_overload.pl 2268 2007-11-06 22:12:20Z mbarbon $
 ## Copyright:   (c) 2001-2003, 2005-2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -20,6 +20,11 @@ use Wx::Overload::Driver;
 
 my( $ovlc, $ovlh ) = ( shift, shift );
 
+if( $ARGV[0] && $ARGV[0] =~ /\.lst$/ ) { # lame hack to read list from file
+    open my $fh, "<", $ARGV[0] or die "$!";
+    @ARGV = map { chomp; $_ } <$fh>;
+}
+
 my $driver = Wx::Overload::Driver->new
   ( files  => \@ARGV,
     header => $ovlh,
